# mulac (Multiagent Computing Framework) 

A simple way to distribute the computing work among a group of process-independent (or thread-independent) agents. 

## Project Homepage 

You can find the source code in https://github.com/csningli/multi-agent-comp.

## Usage

You can refer to https://github.com/csningli/mulac-examples for more examples of the usage of mulac.

## About